==> kubernetes-model-gatewayapi-6.1.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/RouteParentStatusFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.model.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RouteParentStatusFluent<A extends RouteParentStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public List<Condition> getConditions();
  public Condition getCondition(Integer index);
  public Condition getFirstCondition();
  public Condition getLastCondition();
  public Condition getMatchingCondition(Predicate<Condition> predicate);
  public Boolean hasMatchingCondition(Predicate<Condition> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.Condition... conditions);
  public Boolean hasConditions();
  public String getControllerName();
  public A withControllerName(String controllerName);
  public Boolean hasControllerName();
  
  /**
   * This method has been deprecated, please use method buildParentRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParentReference getParentRef();
  public ParentReference buildParentRef();
  public A withParentRef(ParentReference parentRef);
  public Boolean hasParentRef();
  public RouteParentStatusFluent.ParentRefNested<A> withNewParentRef();
  public RouteParentStatusFluent.ParentRefNested<A> withNewParentRefLike(ParentReference item);
  public RouteParentStatusFluent.ParentRefNested<A> editParentRef();
  public RouteParentStatusFluent.ParentRefNested<A> editOrNewParentRef();
  public RouteParentStatusFluent.ParentRefNested<A> editOrNewParentRefLike(ParentReference item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentRefNested<N> extends Nested<N>,ParentReferenceFluent<RouteParentStatusFluent.ParentRefNested<N>>{
    public N and();
    public N endParentRef();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/RouteParentStatusFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.model.Condition;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RouteParentStatusFluent<A extends RouteParentStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(int index,Condition item);
  public A setToConditions(int index,Condition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public List<Condition> getConditions();
  public Condition getCondition(int index);
  public Condition getFirstCondition();
  public Condition getLastCondition();
  public Condition getMatchingCondition(Predicate<Condition> predicate);
  public Boolean hasMatchingCondition(Predicate<Condition> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.Condition... conditions);
  public Boolean hasConditions();
  public String getControllerName();
  public A withControllerName(String controllerName);
  public Boolean hasControllerName();
  
  /**
   * This method has been deprecated, please use method buildParentRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParentReference getParentRef();
  public ParentReference buildParentRef();
  public A withParentRef(ParentReference parentRef);
  public Boolean hasParentRef();
  public RouteParentStatusFluent.ParentRefNested<A> withNewParentRef();
  public RouteParentStatusFluent.ParentRefNested<A> withNewParentRefLike(ParentReference item);
  public RouteParentStatusFluent.ParentRefNested<A> editParentRef();
  public RouteParentStatusFluent.ParentRefNested<A> editOrNewParentRef();
  public RouteParentStatusFluent.ParentRefNested<A> editOrNewParentRefLike(ParentReference item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentRefNested<N> extends Nested<N>,ParentReferenceFluent<RouteParentStatusFluent.ParentRefNested<N>>{
    public N and();
    public N endParentRef();
    
  }
  
}
